@@ -10,7 +10,7 @@ use XTM::generic;
 
 @ISA = qw(Exporter AutoLoader XTM::generic);
 @EXPORT = qw( );
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 =pod
 
@@ -26,16 +26,28 @@ XTM::baseNameString - trivial class definition
 
 Generic container for accessor functions.
 
+=cut
+
+sub xml {
+  my $self   = shift;
+  my $writer = shift;
+
+  $writer->dataElement('baseNameString', $self->string);
+};
+
+=pod
+
 =head1 SEE ALSO
 
 L<XTM>
 
 =head1 AUTHOR INFORMATION
 
-Copyright 2001, Robert Barta <rho@telecoma.net>, All rights reserved.
- 
+Copyright 2001, 2002, Robert Barta <rho@telecoma.net>, All rights reserved.
+
 This library is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
+http://www.perl.com/perl/misc/Artistic.html
 
 =cut
 
